<template>
	<div class="echarts-wrapper" @click="toParentPage" @dblclick="dblclick">
		<div class="echarts-content" ref="chart"></div>
	</div>
</template>

<script>
import * as echarts from 'echarts';
import { WebSocketClass } from '@/assets/js/socket'
import { checkboxs } from '@/assets/js/powerInfoData'
export default {
	name: "RoseChart",
	chart: "",
	chartData: [],
	props: {
		id: {
			type: String,
			default: ""
		}
	},
	data() {
		return {
			websock: null
		}
	},
	methods: {
		findParents(node, select) {
			var parent = node.parentNode;
			if (parent === null || parent.className.indexOf(select) != -1) {
				return parent;
			} else {
				return this.findParents(parent, select);
			}
		},
		dblclick(e) {
			this.isAllScreen = !this.isAllScreen
			let parents = this.findParents(e.currentTarget, 'vdr')
			if (this.isAllScreen) {
				this.parentsStyle = JSON.parse(JSON.stringify(parents.style));
				parents.style.transform = 'none';
				parents.style.width = '100%';
				parents.style.height = '100%';
				parents.style.position = 'fixed';
				parents.style.left = 0;
				parents.style.right = 0;
				parents.style.bottom = 0;
				parents.style.top = 0;
				parents.style.zIndex = 99999;
			} else {
				parents.style.transform = this.parentsStyle.transform;
				parents.style.width = this.parentsStyle.width;
				parents.style.height = this.parentsStyle.height;
				parents.style.position = this.parentsStyle.position;
				parents.style.left = 'initial';
				parents.style.right = 'initial';
				parents.style.bottom = 'initial';
				parents.style.top = 'initial';
				parents.style.zIndex = 'auto';
			}
			this.$options.chart.resize();
		},
		toParentPage(value) {
			if (typeof (value) == 'string') {
				window.parent.parent.postMessage({
					cmd: "syncPage",
					params: {
						pageInfo: {
							label: "设备状态查询",
							name: "btsStatusTest",
							src: "#/dataMager/btsStatus?workStauts=" + value,
							closable: true
						},
					}
				}, "*");
			}
		},
		toParentPage2(value) {
			if (typeof (value) == 'string') {
				window.parent.parent.postMessage({
					cmd: "syncPage",
					params: {
						pageInfo: {
							label: "设备工作状态",
							name: "deviceWorkState",
							src: "#/device-work-state?signalStatus=" + value,
							closable: true
						},
					}
				}, "*");
			}
		},
		setOption(opt) {
			this.$options.chart.setOption(opt);
			this.$options.chart.on('click', (params) => {
				let name;
				if (params.name == '在线浮充') {
					name = '浮充'
					checkboxs.sbzt.map(item => {
						if (item.label == name) {
							this.toParentPage(item.value)
						}
					})
				} else if (params.name == '充电数量') {
					name = '充电'
					checkboxs.sbzt.map(item => {
						if (item.label == name) {
							this.toParentPage(item.value)
						}
					})
				} else if (params.name == '内阻测试数量') {
					name = '内阻测试'
					checkboxs.sbzt.map(item => {
						if (item.label == name) {
							this.toParentPage(item.value)
						}
					})
				} else if (params.name == '通讯故障数量') {
					this.toParentPage2('1')
				} else if (params.name == '核容数量') {
					name = '放电'
					checkboxs.sbzt.map(item => {
						if (item.label == name) {
							this.toParentPage(item.value)
						}
					})
				}
			})
		},
		organizeData(data) {
			let option = {
				legend: [{
					type: "scroll",
					orient: 'vertical',
					align: 'left',
					left: "5%",
					bottom: '1%',
					data: ['核容数量', '内阻测试数量'],
					textStyle: {
						color: '#fff'
					}
				},
				{
					type: "scroll",
					orient: 'vertical',
					left: "40%",
					bottom: '1%',
					align: 'left',
					data: ['在线浮充', '通讯故障数量'],
					textStyle: {
						color: '#fff'
					}
				},
				{
					orient: 'vertical',
					left: "75%",
					bottom: '8%',
					data: ['充电数量', '无用'],
					textStyle: {
						color: '#fff'
					}
				},
				],
				series: [{
					type: 'pie',
					center: ['50%', '50%'],
					radius: ['0', '50%'],
					roseType: 'radius',
					itemStyle: {
						color(params) {
							return data[params.dataIndex].color;
						},
					},
					label: {
						height: 34,
						overflow: 'none',
						distanceToLabelLine: 0,
						formatter: '{a|{b}}\n{hr|}\n{value|{d}%}',
						rich: {
							a: {
								fontSize: 16,
								color: '#fff',
							},
							hr: {
								width: '100%',
								height: 1,
								backgroundColor: '#0073C5'
							},
							value: {
								fontSize: 18,
								color: '#CE6D28',
								fontWeight: 'bold',
								padding: [5, 0, 0, 0]
							}
						},
					},
					labelLine: {
						length: 20,
						length2: 10,
						lineStyle: {
							color: '#0073C5',
							width: 1,
						}
					},
					data: data
				}]
			};

			// 设置图表配置项
			this.setOption(option);
		},
		setData(sendData) {
			if (sendData) {
				this.$options.chartData = sendData;
				this.organizeData(sendData)
			} else {
				this.postData()
			}
		},
		postData() {
			let userId = localStorage.getItem('userId');
			this.websock = new WebSocketClass(`/screen/batteryAlarm/btsStatus/${userId}`, this.wsMessage)
		},
		wsMessage(res) {
			if (res.code == 1) {
				let optionData = [{
					value: 0,
					name: '在线浮充',
					color: '#E85D22'
				},
				{
					value: 0,
					name: '充电数量',
					color: '#76CFDD'
				},
				{
					value: 0,
					name: '内阻测试数量',
					color: '#FEDB5B'
				},
				{
					value: 0,
					name: '通讯故障数量',
					color: '#8278E9'
				},
				{
					value: 0,
					name: '核容数量',
					color: '#9EE6B8'
				},
				]
				let resData = res.data;
				for (let key in resData) {
					optionData.map(item => {
						if (item.name == key) {
							item.value = resData[key]
						}
					})
				}
				this.$options.chartData = optionData;
				this.organizeData(optionData)
			}
		},
		outClear() {
			this.websock.closeMyself()
			this.websock = null
			window.removeEventListener('resize', this.resize);
		},
		resize() {
			setTimeout(() => {
				this.$options.chart.resize();
				if (JSON.stringify(this.$options.chartData) != '{}') {
					this.setData(this.$options.chartData);
				}
			}, 300)
		}
	},
	mounted() {
		// 基于准备好的dom，初始化echarts实例
		this.$options.chart = echarts.init(this.$refs.chart);

		window.addEventListener('resize', this.resize);
	},
	destroyed() {
		window.removeEventListener('resize', this.resize);
	}
}
</script>

<style scoped>
</style>